summaryrefslogtreecommitdiffstats
path: root/kregexpeditor/myfontmetrics.h
diff options
context:
space:
mode:
Diffstat (limited to 'kregexpeditor/myfontmetrics.h')
-rw-r--r--kregexpeditor/myfontmetrics.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kregexpeditor/myfontmetrics.h b/kregexpeditor/myfontmetrics.h
index 649d32b..a8dba88 100644
--- a/kregexpeditor/myfontmetrics.h
+++ b/kregexpeditor/myfontmetrics.h
@@ -17,11 +17,11 @@
**/
#ifndef __MYFONTMETRICS_H
#define __MYFONTMETRICS_H
-#include <qfontmetrics.h>
-#include <qstringlist.h>
+#include <tqfontmetrics.h>
+#include <tqstringlist.h>
-// QFontMetrics::size is broken, therefore I need this hack until it works in QT3
+// TQFontMetrics::size is broken, therefore I need this hack until it works in QT3
-QSize HackCalculateFontSize(QFontMetrics fm, QString str );
+TQSize HackCalculateFontSize(TQFontMetrics fm, TQString str );
#endif